@@ -3,7 +3,6 @@
 # 设置管理域名 & 上传域名
 PUT_URL = ''
 MGR_URL = ''
-GET_URL = ''
 
 # 设置分片上传的块大小和片大小，单位均为字节
 _BLOCK_SIZE = 1024 * 1024 * 4
@@ -25,7 +24,7 @@ logging_folder = '/tmp/logger/'
 tmp_record_folder = '/tmp/sliceupload/'
 
 # 设置分片上传并发线程数
-Thread_num = 4
+Thread_num = 1
 
 class PutPolicy(object):
     
@@ -39,12 +38,12 @@ class PutPolicy(object):
         if key in self.policy:
             self.putpolicy[key] = value
         else:
-            print "invalid putpolicy param\n"
+            print ("invalid putpolicy param\n")
     
     def get_conf(self, key):
   
         if key in self.policy:
             return key + ":" + self.putpolicy[key]
         else:
-            print "invalid putpolicy param\n"
+            print ("invalid putpolicy param\n")
 
