@@ -7,6 +7,7 @@ from wcs.commons.http import _post
 from wcs.commons.http import _get
 from wcs.commons.util import entry
 from wcs.commons.util import get_logger
+from wcs.commons.util import urlsafe_base64_encode
 
 class Fmgr(object):
 
@@ -32,7 +33,7 @@ class Fmgr(object):
         url = '{0}/fmgr/move'.format(self.host)
         data = {'fops': fops}
         if notifyurl is not None:
-            data['notifyURL'] = base64.b64encode(notifyurl)
+            data['notifyURL'] = urlsafe_base64_encode(notifyurl)
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
@@ -46,7 +47,7 @@ class Fmgr(object):
         url = '{0}/fmgr/copy'.format(self.host)
         data = {'fops': fops}
         if notifyurl is not None:
-            data['notifyURL'] = base64.b64encode(notifyurl)
+            data['notifyURL'] = urlsafe_base64_encode(notifyurl)
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
@@ -60,7 +61,7 @@ class Fmgr(object):
         url = '{0}/fmgr/fetch'.format(self.host)
         data = {'fops': fops}
         if notifyurl is not None:
-            data['notifyURL'] = base64.b64encode(notifyurl)
+            data['notifyURL'] = urlsafe_base64_encode(notifyurl)
         if force is not None:
             data['force'] = force
         if separate is not None:
@@ -76,7 +77,7 @@ class Fmgr(object):
         url = '{0}/fmgr/delete'.format(self.host)
         data = {'fops': fops}
         if notifyurl is not None:
-            data['notifyURL'] = base64.b64encode(notifyurl)
+            data['notifyURL'] = urlsafe_base64_encode(notifyurl)
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
@@ -90,7 +91,7 @@ class Fmgr(object):
         url = '{0}/fmgr/deletePrefix'.format(self.host)
         data = {'fops': fops}
         if notifyurl is not None:
-            data['notifyURL'] = base64.b64encode(notifyurl)
+            data['notifyURL'] = urlsafe_base64_encode(notifyurl)
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
@@ -104,13 +105,12 @@ class Fmgr(object):
         url = '{0}/fmgr/deletem3u8'.format(self.host)
         data = {'fops': fops}
         if notifyurl is not None:
-            data['notifyURL'] = base64.b64encode(notifyurl)
+            data['notifyURL'] = urlsafe_base64_encode(notifyurl)
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
         self.logger.info('Deletem3u8 request body is: %s', reqdata)
         self.logger.info('Start to deletem3u8 operation')
-        print reqdata
         code, text = _post(url=url, data=reqdata,headers=self.gernerate_headers(url, body=reqdata))
         self.logger.info('The return code : %d and persistentId/text : %s', code, text)
         return code,text
