@@ -7,6 +7,7 @@ from wcs.commons.http import _post
 from wcs.commons.http import _get
 from wcs.commons.util import entry
 from wcs.commons.util import get_logger
+from wcs.commons.util import urlsafe_base64_encode
 
 class PersistentFop(object):
 
@@ -59,9 +60,9 @@ class PersistentFop(object):
         return headers,reqdata
 
     def execute(self,fops,key,force=None,separate=None,notifyurl=None):
-        data = {'bucket': base64.b64encode(self.bucket), 'key': base64.b64encode(key), 'fops': base64.b64encode(fops)}
+        data = {'bucket': urlsafe_base64_encode(self.bucket), 'key': urlsafe_base64_encode(key), 'fops': urlsafe_base64_encode(fops)}
         if notifyurl is not None:
-            data['notifyURL'] = base64.b64encode(notifyurl)
+            data['notifyURL'] = urlsafe_base64_encode(notifyurl)
         if force == 1:
             data['force'] = 1
         if separate == 1:
