@@ -26,7 +26,8 @@ from wcs.commons.util import get_logger
 from wcs.commons.util import readfile
 from wcs.commons.util import file_to_stream
 from wcs.commons.util import GetUuid
-from uploadprogressrecorder import UploadProgressRecorder
+from wcs.commons.util import urlsafe_base64_encode
+from .uploadprogressrecorder import UploadProgressRecorder
 
 #record_lock = multiprocessing.Lock()
 record_lock = threading.Lock()
@@ -44,9 +45,9 @@ class SliceUpload(object):
         self.key = key
         self.size = os.path.getsize(self.filepath)
         self.params = params
-        self.num = self.size/_BLOCK_SIZE + 1
+        self.num = int(self.size/_BLOCK_SIZE + 1)
         self.status = []
-        self.offsetlist = [i *  _BLOCK_SIZE for i in range(0, self.num)]
+        self.offsetlist = [i *  int(_BLOCK_SIZE) for i in range(0, self.num)]
         self.logger = get_logger(logging_folder, 'sliceupload')
         self.uploadBatch = ''
         self.progress = 0
@@ -71,7 +72,7 @@ class SliceUpload(object):
             else:
                 blocksize = self.size - (blockid * _BLOCK_SIZE)
             self.progress += float(blocksize)/float(self.size)
-            print 'current size: {0:d}, total upload progress: {1:.2f}%'.format(blocksize, self.progress * 100)
+            print('current size: {0:d}, total upload progress: {1:.2f}%'.format(int(blocksize), self.progress * 100))
     
     def recovery_from_record(self):
         record = self.upload_progress_recorder.get_upload_record(self.key)
@@ -178,7 +179,7 @@ class SliceUpload(object):
         if blockid < self.num - 1:
             url = self.block_url(_BLOCK_SIZE, blockid)
         else:
-            url = self.block_url(self.size - (blockid * _BLOCK_SIZE), blockid)
+            url = self.block_url(int(self.size - (blockid * _BLOCK_SIZE)), blockid)
         return url
 
     def make_block(self, offset):
@@ -220,7 +221,7 @@ class SliceUpload(object):
         return offset, bputcode, bputtext['ctx']
       
     def block_url(self, size, blocknum):
-        return '{0}/mkblk/{1}/{2}'.format(PUT_URL, size, blocknum)
+        return '{0}/mkblk/{1}/{2}'.format(PUT_URL, size, int(blocknum))
 
     def block_headers(self,uploadBatch):
         headers = {'Authorization':self.uploadtoken}
@@ -232,7 +233,7 @@ class SliceUpload(object):
         url = ['{0}/mkfile/{1}'.format(host, self.size)]
         if self.params:
             for k, v in self.params.items():
-                url.append('x:{0}/{1}'.format(k, base64.b64encode(v)))
+                url.append('x:{0}/{1}'.format(k, urlsafe_base64_encode(v)))
         url = '/'.join(url)
         return url
 
