@@ -46,6 +46,12 @@ class WsLive(object):
         if query is not None:
             self.logger.info('List params is %s', query)
         self.logger.info('List bucket %s', bucket)
+        print("wslive_list:"+url)
+        print("\n")
+        print(query)
+        print("\n")
+        print(self.gernerate_headers(url))
+        print("\n")
         code, text = _get(url=url, data=query, headers=self.gernerate_headers(url)) 
         self.logger.info('The return code : %d and text : %s', code, text)
         return code, text 
